#ifndef __RANSAC_H__
#define __RANSAC_H__

/* RANSAC Scoring */
typedef struct {
	/* number of inliers, rectangular gain function */
	unsigned I;
	/* MSAC scoring, truncated quadratic gain function */
	double J;
} Score;

/* Parameter list
   ==============
name     - Input/Output - type and size - description                                                        - default value in `simple' variants F/H
----------------------------------------------------------------------------------------------------------------------------------------------------
u        - I            - double 6xlen  - input data - tentative correspondences                             - NA
len      - I            - int scalar    - length of input tentative correspondences                          - NA
th       - I            - double scalar - squared inlier-outlier error threshold (px^2)                      - NA
conf     - I            - double scalar - user-required probability of obtaining the best solution           - 0.95
max_sam  - I            - int scalar    - maximal number of samples drawn                                    - 1000,000
F/H      - O            - double 3x3    - fundamental matrix/homography matrix                               - NA
inl      - O            - binary 1xlen  - inlier/outlier separation                                          - NULL (not returned)
do_lo    - I            - binary        - turning LO on/off                                                  - 1
inlLimit - I            - int           - maximal number of inliers for iterative lest squares, 0 = no limit - 49/28
----------------------------------------------------------------------------------------------------------------------------------------------------

All the matrices are stored column-wise (Matlab-like)!
*/

/* LO-RANSAC */
Score ransacF (double *u, int len, double th, double conf, int max_sam,
			double *F, unsigned char * inl, int do_lo, int inlLimit);

/* LO-RANSAC as simply as possible */
void ransacFsimple (double *u, int len, double th, double *F);

/* LO-RANSAC */
Score ransacH (double *u, int len, double th, double conf, int max_sam,
			double *H, unsigned char * inl, int do_lo, int inlLimit);

/* LO-RANSAC as simply as possible */
void ransacHsimple (double *u, int len, double th, double *H);

#endif /* __RANSAC_H__ */
